@@ -1,8 +1,10 @@
 #include "dstream.hh"
 #include "matrix.hh"
 
-static Dstream *dout = new Dstream(0,0);
-
+static Dstream *dout = 0;
+/**
+  Set the debugging output. Will not delete/swallow argument.
+ */
 void set_matrix_debug(Dstream&ds)
 {
     dout = &ds;
@@ -10,8 +12,9 @@ void set_matrix_debug(Dstream&ds)
 
 Matrix::operator String() const
 {
-    String s("matrix {\n");
+    String s;
 #ifndef NPRINT
+    s="matrix {\n";
     for (int i=0; i< rows(); i++){
 	for (int j = 0; j < cols(); j++) {
 	    s+= String(dat->elem(i,j), "%6f ");
@@ -28,19 +31,22 @@ void
 Matrix::print() const
 {
 #ifndef NPRINT
+    if (!dout)
+	return;
     *dout << *this;
 #endif
 }
 
 Vector::operator String() const
 {
-    String s("vector [");
+    String s;
 #ifndef NPRINT
+    s="vector [";
     for (int i=0; i < dim(); i++) {
 	s += String(dat[i], "%6f") + String(' ');
     }
-#endif
     s+="]";
+#endif
     return s;
 }
 
@@ -49,6 +55,8 @@ void
 Vector::print() const
 {
 #ifndef NDEBUG
+    if (!dout)
+	return;
     *dout << *this<<'\n';
 #endif
 }
